# -*- coding: utf-8 -*-
__author__ = 'janmeier'
SCARFACE_DEFAULT_PLATFORM_STRATEGIES = [
    'scarface.platform_strategy.APNPlatformStrategy',
    'scarface.platform_strategy.APNSSandboxPlatformStrategy',
    'scarface.platform_strategy.GCMPlatformStrategy'
]